<?php

class LearnDash_Content_Filters extends WECR_Content_Filters{

	function __construct(){
		add_filter( 'sfwd_lms_has_access', array( $this, 'wecr_learndash_access' ), 10, 3 );
		add_filter( 'learndash_payment_button', array( $this, 'remove_learndash_payment_button' ), 10, 2 );
	}

	/**
	 * Removes the learndash payment button because we're doing our own thing
	 *
	 * @since 1.0
	 * @author SFNdesign, Curtis McHale
	 *
	 * @param       string      $button             required                    LearnDash HTML button
	 * @param       array       $payment_params     required                    LearnDash Payment params
	 * @uses        $this->should_content_be_restricted()                       Returns true if given post_id shoudl be restricted
	 * @uses        $this->user_purchased_product()                             Returns true if the user purchased a product that restricts the given post_id
	 * @return      string/nothing                                              Nothing if the user hasn't purchased the product
	 */
	function remove_learndash_payment_button( $button, $payment_params ){

		if ( $this->should_content_be_restricted( get_the_ID() ) && ! $this->user_purchased_product( get_the_ID() ) ) return '';

		return $button;
	}

	/**
	 * Returns true if user can access a course
	 *
	 * @since 1.0
	 * @author SFNdesign, Curtis McHale
	 *
	 * @param       bool            $has_access
	 */
	function wecr_learndash_access( $has_access, $post_id, $user_id ){

		if ( $this->user_has_admin_access() ) return true;
		if ( $this->should_content_be_restricted( absint( $post_id ) ) && ! $this->user_purchased_product( absint( $post_id ) ) ) return false;

		return $has_access;
	}

}
$GLOBALS['learndash_content_filters'] = new LearnDash_Content_Filters();
